function matprint(m, dropMax, headings)
% matPrint: Print a matrix with special features and formatting
% ---------------------------------------
% TASK:
%   Print a matrix with special features and formatting
%   Options:
%   - set everything to zero below a certain upper bound
%   - display column headings
%   - each column is formatted appropriately to show a fixed number
%       of significant decimals for the maximum element
% IN:
%  m = the matrix
%  [optional]
%   - dropMax   = drop everything that is smaller than dropMax in
%       absolute value; 0 => drop nothing
%   - headings  = string of column headings, may be empty
% OUT:
%   --
% REM:
%   - each column is 10 characters wide

% ERRORS:
%
% TEST:
%   t_matprn
% AUTHOR: Lutz Hendricks, 1993
% ---------------------------------------

%   *********  INPUT CHECK  *******************

    if nargin < 1  |  isempty(m)
        error('m empty')
    end

    if nargin < 3
        showHdg = 0;
    elseif  isempty(headings)
        showHdg = 0;
    else
        showHdg = 1;
        if ~isstr(headings)
          error('Headings must be strings')
        end
    end

    if nargin < 2
        dropMax = 0;
    elseif isempty(dropMax)
        error('dropMax undefined');
    elseif dropMax < 0
        error('dropMax must be positive')
    end

    [ rm, cm ] = size(m);



%   *********  DROP SMALL ELEMENTS  ************

    if dropMax > 0
        m = m .* (abs(m) >= dropMax);
    end

%   *********  SCALE FACTORS  ******************

    % find largest elements; note that max() handles vectors differently
    % from matrices.
    if rm > 1
        maxVec = max(abs(m));
    else
        maxVec = abs(m);
    end

    for i=1:cm
      if maxVec(i) < 1
        scaleVec(i) = 1;
      else
        scaleVec(i) = floor( log10(maxVec(i)) );
      end
    end

    %   Omit scale factors of less than 10^(+-2)
    scaleVec = scaleVec .* ( abs(scaleVec) > 1 );

    %  exponents of 10 to divide by
    scaleFactor = 10 .^ scaleVec;
    %   divide columns by scale factors
    mp = zeros(rm, cm);
    for i=1:cm
      mp(:,i) = m(:,i) ./ scaleFactor(i);
    end

%   **********  PRINT  *************************

    if showHdg == 1
        disp(headings)
    end

    if any( scaleVec ~= 0 )
        scaleStr = 'Scales  ';
        for i = 1:cm;
          scaleStr = [ scaleStr, int2str(scaleVec(i)), '        ' ];
        end
        disp(scaleStr)
        %   disp('Values')
    end

    disp(mp)
    disp(' ')

% *** end function ***
