function [maxVal, maxRow, maxCol] = maxidx(M);
% Return the max value in a matrix together with its row and column index
% ---------------------------------------
% TASK:
%
% IN:
%   M       matrix or vector
% OUT:
%   maxVal  max value
%   maxRow  row of max value
%   maxCol  col of max value
% ---------------------------------------

% REM:
%   - does not handle multiple identical max values
% ERRORS:
%
% TEST:
%   t_maxidx()
% AUTHOR: Lutz Hendricks, 1994
% ---------------------------------------

    [rn, cn] = size(M);
    
    % ****  Handle the case of a vector  ****
    if rn == 0
        abort('MaxIdx:  Input M empty');
    elseif rn == 1  |  cn == 1
        maxVal = max(M);
        for i = 1 : length(M)
            if M(i) >= maxVal
                maxIdx = i;
                break;
            end
        end            
        if rn == 1
            maxRow = 1;
            maxCol = maxIdx;
        else
            maxCol = 1;
            maxRow = maxIdx;
        end
        return
    end

    % Compute column maxima
    [ cMax, cMaxRow ] = max(M);
    
    % Compute row maxima
    [ rMax, rMaxCol ] = max(M');
    
    maxVal = max(cMax);
    
    % Row of max
    for i = 1:cols(M)
        if cMax(i) == maxVal
            maxRow = cMaxRow(i);
            break;
        end
    end
    
    % Col of max
    for i = 1:rows(M)
        if rMax(i) == maxVal
            maxCol = rMaxCol(i);
            break;
        end
    end


% *** end function ***
