function pv = prvalue(x, r, dbg)
% Compute the present value of the stream x
% ---------------------------------------
% IN:
%   x = stream of values (1xT)
%   r = discount rates (1xT)
% OUT:
%   present value

% REM:
% - inputs can be row or column vectors
% TEST:     t_prval
% AUTHOR: Lutz Hendricks, 1993
% ---------------------------------------

% ****** INPUT CHECK *******

    if nargin < 3
        dbg = 0;
    end

    % Check for plausibility of interest rates
    if any( r < -0.2 )
        disp( min(r) );
        warnmsg('PrValue:  Implausibly low r values.');
        pause2;
    end


% ****** COMPUTATION *******

    pv = sum( x ./ cumprod((1+r)) );

%    if any(any( size(pv) ~= [1,1] ))
%        abort('Return value not scalar')
%    end

%   disp('PRVALUE:')
%   matprint( [x',dFactors',(x./dFactors)',(1+r)'], 0, ...
%    '       -x-  dFactors   x/dFact.       1+r' )

% *** end function ***

