function [v1,v2,v3,v4,v5,v6,v7,v8,v9,v10,v11,v12,v13,v14,v15,v16,v17,v18,v19,v20]...
= v_split(x, lv, dbg);
% Split vector x into sub-vectors whose lengths are given in vector lv
% ---------------------------------------
% TASK:
%
% IN:
%  x        vector
%  lv       vector of lengths of subvectors. 1xN
% OUT:
%  v1...    sub-vectors of given lengths. The last vector contains the remainder of x
%           after N vectors have been filled.
% ---------------------------------------

% REM:
%
% ERRORS:
%  - x too short
%  - lv longer than 19
% TEST:
%  T_VSPLIT
% AUTHOR: Lutz Hendricks, 1995
% ---------------------------------------

% *******  CONSTANTS  *******

   global UNDEFINED
   fName = 'V_SPLIT';
   % Max no of vectors one can return (plus one for remainder, if any)
   maxN = 19;
   N = length(lv);
   xLen = length(x);


% *******  INPUT CHECK  ********

   if N > maxN
      N
      maxN
      abort([ fName, ':  N > maxN' ]);
   end

   cumLen = cumsum(lv);
   if cumLen(N) > xLen
      abort([ fName, ':  cumLen(N) > length(x)' ]);
   end

   if dbg > 0
      % Compare no. of output arg's with no. of vectors requested
      %  With or without remainder
      if nargout ~= N  &  nargout ~= N+1
         warnmsg([ fName, ':  nargout suspicious' ]);
      end

      % If N = 1, probably v_split1 was intended
      if N == 1
         warnmsg([ fName, ':  Use v_split1 to get vectors of equal length.' ]);
      end
   end

% *****************  M A I N  *****************

   % Construct a vector of starting indexes. 1xN
   %  The first is 1. Second: lv(1)+1. Third: lv(1)+lv(2)+1
   %  Nth: sum(lv(1:N-1))+1
   startIdx = [1, cumLen(1:N-1)+1];

   % Construct a vector of ending indexes. 1xN
   endIdx = cumLen;

   for i = 1 : N
      iStr = int2str(i);
      % vi = x( startIdx(i) : endIdx(i) );
      vi = x( startIdx(i) : endIdx(i) );
      eval([ 'v', iStr, ' = vi;' ]);
   end

   % Set remainder.
   %  Set to undefined, if there is none
   if cumLen(N) < xLen
      vRem = x( endIdx(i) + 1 : xLen );
      eval([ 'v', int2str(N+1), ' = vRem;' ]);
   else
      eval([ 'v', int2str(N+1), ' = UNDEFINED;' ]);
   end

   % Set all other vi's to UNDEFINED
   %  Start at N+2 in order not to overwrite remainder
   if N < maxN
      for i = N+2 : maxN+1
         eval([ 'v', int2str(i), ' = UNDEFINED;' ]);
      end
   end


% *** end function ***
